interface MulticallElement {
    readonly target: string;
    readonly entrypoint: string;
    readonly calldata: string[];
}
interface MulticallProps {
    calls: MulticallElement[];
}
interface EVMFunction {
    readonly type: 'function';
    readonly name: string;
    readonly inputs: ReadonlyArray<ParameterDescription>;
    readonly outputs?: ReadonlyArray<ParameterDescription>;
    readonly stateMutability?: 'pure' | 'view' | 'nonpayable' | 'payable';
}
interface ParameterDescription {
    readonly name: string;
    readonly type: string;
    readonly internalType?: string;
    readonly components?: ReadonlyArray<ParameterDescription>;
}
type Encodable = EncodablePrimitive | EncodableTuple | EncodableArray;
type EncodablePrimitive = Uint8Array | string | boolean | bigint;
interface EncodableTuple {
    [x: string]: Encodable;
}
interface EncodableArray extends ReadonlyArray<Encodable> {
}
interface Call {
    entry_point: string;
    contract_address: string;
    calldata: string[];
}

type index_Call = Call;
type index_EVMFunction = EVMFunction;
type index_Encodable = Encodable;
type index_EncodableArray = EncodableArray;
type index_EncodablePrimitive = EncodablePrimitive;
type index_EncodableTuple = EncodableTuple;
type index_MulticallElement = MulticallElement;
type index_MulticallProps = MulticallProps;
type index_ParameterDescription = ParameterDescription;
declare namespace index {
  export type { index_Call as Call, index_EVMFunction as EVMFunction, index_Encodable as Encodable, index_EncodableArray as EncodableArray, index_EncodablePrimitive as EncodablePrimitive, index_EncodableTuple as EncodableTuple, index_MulticallElement as MulticallElement, index_MulticallProps as MulticallProps, index_ParameterDescription as ParameterDescription };
}

declare function prepareMulticallCalldata(calls: Call[]): string;

declare function parseSignature(functionSignature: string): EVMFunction;
declare function generateFullSignature(functionDescription: EVMFunction): string;
declare function generateCanonicalSignature(functionDescription: EVMFunction): string;
declare function encodeMethod(keccak256: (message: Uint8Array) => Promise<bigint>, functionDescription: EVMFunction, parameters: EncodableArray): Promise<Uint8Array>;
declare function encodeMethod(keccak256: (message: Uint8Array) => Promise<bigint>, functionSignature: string, parameters: EncodableArray): Promise<Uint8Array>;
declare function encodeMethod(functionSelector: number, parameterDescriptions: ReadonlyArray<ParameterDescription>, parameters: EncodableArray): Uint8Array;
declare function encodeParameters(descriptions: ReadonlyArray<ParameterDescription>, parameters: EncodableArray): Uint8Array;

export { encodeMethod, encodeParameters, generateCanonicalSignature, generateFullSignature, parseSignature, prepareMulticallCalldata, index as types };
